==> haskell-text-format-0.3.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-format
version: 0.3.2
id: text-format-0.3.2-67T9bQauYNZAnMdUUpZqLP
key: text-format-0.3.2-67T9bQauYNZAnMdUUpZqLP
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/text-format
synopsis: Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.
category: Text
abi: a9002624b1b02114eebee9c072061685
exposed: True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal
hidden-modules: Data.Text.Format.Functions Data.Text.Format.Int
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-format-0.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-format-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-format-0.3.2
hs-libraries: HStext-format-0.3.2-67T9bQauYNZAnMdUUpZqLP
depends:
    array-0.5.3.0 base-4.12.0.0
    double-conversion-2.0.2.0-5I8QLOXTNnCLn9zzKU1qAc ghc-prim-0.5.3
    integer-gmp-1.0.2.0 old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html: /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-format-0.3.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-format
version: 0.3.2
id: text-format-0.3.2-7KNQ2aPP1qZClbKyz3avr5
key: text-format-0.3.2-7KNQ2aPP1qZClbKyz3avr5
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/text-format
synopsis: Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.
category: Text
abi: 6cf66f5430ceda5f67032b7117a0981b
exposed: True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal
hidden-modules: Data.Text.Format.Functions Data.Text.Format.Int
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-format-0.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-format-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-format-0.3.2
hs-libraries: HStext-format-0.3.2-7KNQ2aPP1qZClbKyz3avr5
depends:
    array-0.5.3.0 base-4.12.0.0
    double-conversion-2.0.2.0-1KkJutkoP2qJcsxQMMncw9 ghc-prim-0.5.3
    integer-gmp-1.0.2.0 old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html: /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
